@@ -159,8 +159,9 @@ twosamples.formula <-
       rr <- do.call("twosamples", c(DATA, paired = FALSE, list(...)))
     }
   }
-##  attr(rr, "data.name") <- DNAME
-  structure(rr, formula=formula, data.name=format(substitute(data)))
+  ##  attr(rr, "data.name") <- DNAME
+  ldn <- substitute(data)
+  structure(rr, formula=formula, data.name=if (is.name(ldn)) format.default(ldn))
 }
 ## ========================================================================
 qintpol <- function(p, par1, par2, dist="binom")
@@ -197,7 +198,7 @@ inference <-
   if (is.null(se))
     if (NCOL(estimate)>1) {
       se <- estimate[,2]
-      estimate <- estimate[,1]
+      estimate <- structure(estimate[,1], names=row.names(estimate))
     }
   if (is.null(se)) se <- attr(estimate, "se")
   if (is.null(se))
@@ -274,7 +275,12 @@ termtable <- #f
                      if (length(ldist)) c(" ; distribution = ", ldist),
                      " :  Drop-term effects"),
                    collapse="")
-  ldname <- as.character(object$call$data)
+  ldname <- attr(object, "data.name")
+  if (length(ldname)==0) ldname <- object$call$data
+  ldname <- if (is.language(ldname)) as.character(ldname)
+            else {
+              if (!is.character(ldname)) ldname
+            }
   ## if ((inherits(object, "glm") &&
   ##      lfamily %in% c("poisson","quasipoisson")) ||
   ##     (inherits(object, "survreg")&&
@@ -664,6 +670,10 @@ termeffects <- #f
   structure(res, class="termeffects", head=lmethod)
 } ## end termeffects
 ## -------------------------------------------------------------------------
+"[.termeffects" <- #f
+  function(x, i=NULL)  structure(unclass(x)[i], class="termeffects")
+    ## unclass  avoids infinite recursion!
+## -------------------------------------------------------------------------
 print.inference <- #f
   function (x, show = getOption("show.inference"), print=TRUE,
             digits = getOption("digits.reduced"), 
@@ -698,11 +708,12 @@ print.inference <- #f
   if ("nocoef"%nin%lshow) lshow <- c("coef", lshow)
   if (any(c("statistic","p.value","Sig0")%in%lshow)) lshow <- c(lshow,"test")
   ## ---
+  ldn <- attr(x, "data.name")
+  if (!(is.character(ldn)&length(ldn)==1)) ldn <- NULL
   lout <- c(
-    if (length(ldn <- attr(x, "data.name"))) paste("data: ", ldn),
+    if (length(ldn)) paste("data: ", ldn),
     if (length(lfo <- attr(x, "formula")))
-##-       format(paste("formula: ", paste(format(lfo),collapse="")))
-      paste("target variable: ", format(lfo[[2]]) )
+      paste("target variable: ", as.character(lfo[[2]]) ) ## was format()
   )
   lhead <- c(
     paste(attr(x, "method"),"\n",collapse="  "),
@@ -716,7 +727,8 @@ print.inference <- #f
         paste(if(length(leffn <- attr(x, "effectname")))
           paste(leffn, ": ",sep="") else "effect:   ", format(leff)),
       if (getOption("show.confint")) {
-        if (length(lci <- x[c("ciLow","ciUp")]))
+        lci <- x[c("ciLow","ciUp")]
+        if (any(!is.na(lci)))
           paste(" ;  confidence int.: [",
                 paste(format(lci), collapse=", "),"]\n")
         else "\n"
@@ -818,21 +830,22 @@ print.printInference <- #f
 {
   ltail <- NULL
   if (is.list(x)&!is.data.frame(x)) {
-    if (length(lt <- attr(x,"head"))) cat("\n", lt, sep="")
+    if (length(lt <- attr(x,"head"))) cat(lt, "\n", sep="")
     ltail <- attr(x,"tail")
   } else x <- list(x)
   lInam <- length(lnam <- names(x))
   ## -------------------------------------
   for (li in seq_along(x)) {
-    if (lInam) cat("\n$",lnam[li],"\n")
+    if (lInam) cat(lnam[li],"\n")
     lx <- x[[li]]
-    class(lx) <- setdiff(class(lx), "printInference")
+    class(lx) <- setdiff(class(lx), c("printInference", "inference"))
     if (length(lt <- attr(lx,"head"))) cat(lt, "\n", sep="")
     if (length(dim(lx))) print(lx)
     else {
       if(length(names(lx))) print(c(lx), quote=FALSE) else cat(lx, sep="")
     }
     if (length(lt <- attr(lx,"tail"))) cat(lt, sep="")
+    cat("\n")
   }
   if (length(ltail)) cat(ltail, sep="") 
   cat("\n")
@@ -893,9 +906,13 @@ print.termeffects <- #f
     return()
   }
   for (li in seq_along(lx)) {
-    lr <- print.inference(lx[[li]], show=show, transpose.ok=transpose.ok, print=FALSE)
+    lxx <- lx[[li]]
+    lr <- if (length(lxx)>1) {
+            print.inference(lxx, show=show, transpose.ok=transpose.ok, print=FALSE)
+            } else format(lxx) ## e.g., "(Intercept)"
     ltail <- attr(lr,"tail")
     attr(lr, "head") <- attr(lr,"tail") <- NULL
+    if (length(lr)==1) lr <- paste("   ", lr)
     lx[[li]] <- lr
   }
   rr <- structure(lx, class="printInference",
@@ -916,7 +933,7 @@ plot.inference <- #f
 ##-     lncmax <- 1.5*par("fin")[1]/par("cin")[1]
 ##-     lcexsub <- min(1,max(0.5, lncmax/lnc))
 ##-     if (lcexsub==0.5) sub <- shortenstring(sub, lncmax/lcexsub)
-##-   }
+  ##-   }
   lframecol <- plpars[["framecol"]]
   lwd <- rep(c(plpars[["lwd"]],2), length=3)
   if (is.null(dim(x))) x <- rbind(x)
@@ -969,6 +986,8 @@ plot.termeffects <- #f
     x <- x[llen>1]
     llen <- llen[llen>1]
   }
+  if (length(llen)==0)
+    stop("!plot.termeffects! No termeffects", if(single) "with length >1")
   if (length(llen)==1) {
     plot.inference(x[[1]], pos=pos, plpars=plpars, xlab=xlab, ...) ## sub=sub, 
     return()
@@ -1056,7 +1075,8 @@ rlv.symbols <- list(symbol=c(" ", ".", "+", "++", "+++"),
 relevance.options <- list(
   digits.reduced = 3,
   testlevel = 0.05,
-  rlv.threshold = c(stand=0.1, rel=0.1, prop=0.1, coef=0.1, drop=0.1, pred=0.05),
+  rlv.threshold =
+    c(stand=0.1, rel=0.1, prop=0.1, corr=0.1, coef=0.1, drop=0.1, pred=0.05),
   termtable = TRUE, 
   show.confint = TRUE, show.doc = TRUE, 
   show.inference = "relevance",
